@@ -1,11 +1,12 @@
 # -*- coding: utf-8 -*-
 import datetime
+import typing
 from enum import IntEnum
 from pathlib import Path
 from typing import Type, Sequence, Any
 
 import grpc
-from pydantic import BaseModel
+from pydantic import BaseModel, Field
 from typing_extensions import get_args, get_origin
 from jinja2 import Template
 from google.protobuf.descriptor import (
@@ -16,24 +17,8 @@ from google.protobuf.descriptor import (
 )
 
 from fast_grpc.service import Service, MethodMode
-from fast_grpc.types import Empty
-from fast_grpc.types import (
-    BoolValue,
-    BytesValue,
-    Double,
-    DoubleValue,
-    FloatValue,
-    Int32,
-    Int32Value,
-    Int64,
-    Int64Value,
-    StringValue,
-    Uint32,
-    UInt32Value,
-    Uint64,
-    UInt64Value,
-)
-from fast_grpc.utils import protoc_compile
+from fast_grpc.types import Empty, ProtoTag, PYTHON_TO_PROTOBUF_TYPES
+from fast_grpc.utils import protoc_compile, camel_to_snake
 
 _base_types = {
     bytes: "bytes",
@@ -45,23 +30,6 @@ _base_types = {
     # Date and time
     datetime.datetime: "string",
     str: "string",
-    Uint32: "uint32",
-    Uint64: "uint64",
-    Int32: "int32",
-    Int64: "int64",
-    Double: "double",
-}
-
-_wrapper_types = {
-    BoolValue: "google.protobuf.BoolValue",
-    BytesValue: "google.protobuf.BytesValue",
-    DoubleValue: "google.protobuf.DoubleValue",
-    FloatValue: "google.protobuf.FloatValue",
-    Int32Value: "google.protobuf.Int32Value",
-    Int64Value: "google.protobuf.Int64Value",
-    StringValue: "google.protobuf.StringValue",
-    UInt32Value: "google.protobuf.UInt32Value",
-    UInt64Value: "google.protobuf.UInt64Value",
 }
 
 # 定义 Jinja2 模板
@@ -69,16 +37,11 @@ PROTO_TEMPLATE = """
 syntax = "proto3";
 
 package {{ proto_define.package }};
-
-{% for service in proto_define.services %}
-service {{ service.name }} {
-    {% for method in service.methods -%}
-    rpc {{ method.name }}({{ method.request }}) returns ({{ method.response }});
-    {%- if not loop.last %}
-    {% endif %}
-    {%- endfor %}
-}
-{% endfor %}
+{% for depend in proto_define.dependencies %}
+{%- if depend %}
+import "{{ depend }}";
+{%- endif %}
+{%- endfor %}
 {% for enum in proto_define.enums.values() %}
 enum {{ enum.name }} {
     {% for field in enum.fields -%}
@@ -97,6 +60,15 @@ message {{ message.name }} {
     {%- endfor %}
 }
 {% endfor %}
+{% for service in proto_define.services %}
+service {{ service.name }} {
+    {% for method in service.methods -%}
+    rpc {{ method.name }}({{ method.request }}) returns ({{ method.response }});
+    {%- if not loop.last %}
+    {% endif %}
+    {%- endfor %}
+}
+{% endfor %}
 """
 PYTHON_TEMPLATE = """
 import grpc
@@ -110,7 +82,6 @@ class {{ enum.name }}(IntEnum):
     {%- for field in enum.fields %}
     {{ field.name }} = {{ field.index }}
     {%- endfor %}
-
 {% endfor %}
 {% for message in proto_define.messages.values() %}
 class {{ message.name }}(BaseModel):
@@ -120,7 +91,7 @@ class {{ message.name }}(BaseModel):
     {%- endfor %}
     {% else %}
     pass
-    {% endif %}
+    {%- endif %}
 {% endfor %}
 {% for service in proto_define.services %}
 class {{ service.name }}Client:
@@ -173,6 +144,7 @@ class ProtoDefine(BaseModel):
     services: list[ProtoService]
     messages: dict[Any, ProtoStruct]
     enums: dict[Any, ProtoStruct]
+    dependencies: set[str] = Field(default_factory=set)
 
     def render(self, proto_template) -> str:
         template = Template(proto_template)
@@ -193,6 +165,8 @@ def generate_type_name(type_: type) -> str:
     """
     if not isinstance(type_, type):
         raise ValueError(f"'{type_}' must be a type")
+    if type_ in (bytes, int, float, bool, str, datetime.datetime):
+        return type_.__name__.capitalize()
     origin = get_origin(type_)
     args = get_args(type_)
     if origin is None:
@@ -205,15 +179,12 @@ def generate_type_name(type_: type) -> str:
             return "".join(type_names + [origin.__name__])
         if issubclass(type_, IntEnum):
             return type_.__name__
-        if not issubclass(type_, tuple(_base_types)):
-            raise ValueError(f"Unsupported type: {type_}")
-        return type_.__name__.capitalize()
     else:
         if issubclass(origin, Sequence):
             return f"{generate_type_name(args[0])}List"
         if issubclass(origin, dict):
             return f"{generate_type_name(args[0])}{generate_type_name(args[1])}Dict"
-        raise ValueError(f"Unsupported type: {type_}")
+    raise ValueError(f"Unsupported type: {type_}")
 
 
 class ProtoBuilder:
@@ -245,8 +216,8 @@ class ProtoBuilder:
         if schema in self._proto_define.messages:
             return self._proto_define.messages[schema]
         message = ProtoStruct(name=generate_type_name(schema), fields=[])
-        for i, (name, field) in enumerate(schema.model_fields.items(), 1):
-            type_name = self._get_type_name(field.annotation)
+        for i, name in enumerate(schema.model_fields.keys(), 1):
+            type_name = self._get_type_name(schema.__annotations__[name])
             message.fields.append(ProtoField(name=name, type=type_name, index=i))
         self._proto_define.messages[schema] = message
         return message
@@ -254,18 +225,38 @@ class ProtoBuilder:
     def convert_enum(self, schema: Type[IntEnum]):
         if schema in self._proto_define.enums:
             return self._proto_define.enums[schema]
+        member_prefix = camel_to_snake(schema.__name__).upper()
         enum_struct = ProtoStruct(
             name=schema.__name__,
             fields=[
-                ProtoField(name=member.name, index=member.value) for member in schema
+                ProtoField(
+                    name=member.name
+                    if member.name.startswith(member_prefix)
+                    else f"{member_prefix}_{member.name}",
+                    index=member.value,
+                )
+                for member in schema
             ],
         )
         self._proto_define.enums[schema] = enum_struct
         return enum_struct
 
-    def _get_type_name(self, type_: type) -> str:
+    def _get_type_name(self, type_: Any) -> str:
         origin = get_origin(type_)
         args = get_args(type_)
+        if type_ in PYTHON_TO_PROTOBUF_TYPES:
+            tag = PYTHON_TO_PROTOBUF_TYPES[type_]
+            self._proto_define.dependencies.add(tag.package)
+            return tag.name
+        if origin is typing.Annotated:
+            for tag in args[1:]:
+                if isinstance(tag, ProtoTag):
+                    self._proto_define.dependencies.add(tag.package)
+                    return tag.name
+            return self._get_type_name(args[0])
+        if origin is typing.Union:
+            _args = [i for i in args if i is not type(None)]
+            return self._get_type_name(_args[0])
         if origin is None:
             if issubclass(type_, BaseModel):
                 message = self.convert_message(type_)
@@ -273,15 +264,12 @@ class ProtoBuilder:
             if issubclass(type_, IntEnum):
                 struct = self.convert_enum(type_)
                 return struct.name
-            if not issubclass(type_, tuple(_base_types)):
-                raise ValueError(f"Unsupported type: {type_}")
-            return _base_types[type_]
         else:
             if issubclass(origin, Sequence):
                 return f"repeated {self._get_type_name(args[0])}"
             if issubclass(origin, dict):
                 return f"map <{self._get_type_name(args[0])}, {self._get_type_name(args[1])}>"
-            raise ValueError(f"Unsupported type: {type_}")
+        raise ValueError(f"Unsupported type: {type_}")
 
 
 class ClientBuilder:
@@ -339,10 +327,14 @@ class ClientBuilder:
         if enum_meta in self._proto_define.enums:
             return self._proto_define.enums[enum_meta]
         name = self._gen_class_name(enum_meta.full_name)
+        member_prefix = camel_to_snake(name).upper()
         enum_struct = ProtoStruct(
             name=name,
             fields=[
-                ProtoField(name=name, index=value.index)
+                ProtoField(
+                    name=name.removeprefix(member_prefix).removeprefix("_"),
+                    index=value.index,
+                )
                 for name, value in enum_meta.values_by_name.items()
             ],
         )
